@@ -30,6 +30,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QAbstractEventDispatcher>
 #include <QPluginLoader>
 #include <QSocketNotifier>
+#include <QStyle>
 #include <QThread>
 #include <QtConcurrentRun>
 
@@ -80,6 +81,9 @@ WaylandTestApplication::~WaylandTestApplication()
         }
         waylandServer()->destroyXWaylandConnection();
     }
+    if (QStyle *s = style()) {
+        s->unpolish(this);
+    }
     waylandServer()->terminateClientConnections();
     destroyCompositor();
 }
